import requests as req
import json


RIMINDER_API_URL = "https://www.riminder.net/sf/public/api/v1.0/"


class Riminder(object):

    def __init__(self, api_key, webhook_secret=None):
        self.auth_header = {
            "X-API-Key": api_key
        }
        self.webhook_secret = webhook_secret

    def _create_request_url(self, resource_url):
        return "{api_endpoint}{resource_url}".format(
            api_endpoint=RIMINDER_API_URL,
            resource_url=resource_url
        )

    def _fill_headers(self, header):
        res = {}
        for key, value in header.items():
            res[key] = value
        return res

    def get(self, resource_endpoint, query_params={}, headers={}):
        url = self._create_request_url(resource_endpoint)
        header = self._fill_headers(self.auth_header)
        header = {**header, **self._fill_headers(headers)}
        if query_params:
            return req.get(url, headers=self.auth_header, params=query_params)
        else:
            return req.get(url, headers=self.auth_header)

    def post(self, resource_endpoint, data={}, files=None, headers={}):
        url = self._create_request_url(resource_endpoint)
        header = self._fill_headers(self.auth_header)
        header = {**header, **self._fill_headers(headers)}
        if files:
            return req.post(url, headers=header, files=files, data=data)
        else:
            return req.post(url, headers=header, data=data)

    def patch(self, resource_endpoint, data={}, headers={}):
        url = self._create_request_url(resource_endpoint)
        header = self._fill_headers(self.auth_header)
        header = {**header, **self._fill_headers(headers)}
        return req.patch(url, headers=self.auth_header, json=data)



import unittest
import hmac
import hashlib
import base64
import json

from riminder import Riminder
from profile import Profile
from source import Source
from filter import Filter
from webhook import Webhook, EVENT_FILTER_SCORE_ERROR


class TestHelper:
    def __init__(self):
        self.api_key = ""
        self.webhook_secret = 'totaly_a_valid_secret_key'
        self.source_id = None
        self.add_source_id = None
        self.profile_id = None
        self.profile_ref = None
        self.filter_id = None
        self.filter_ref = None
        self.rating = int(1)
        self.stage = 'NEW'
        self.source_type = 'api'
        # if source_name is empty no name is selected
        self.source_name = []

    def getKey(self):
        return self.api_key

    def getWebhookSecret(self):
        return self.webhook_secret

    def setup(self):
        api = Riminder(api_key=self.api_key)
        api_source = Source(api)
        api_profile = Profile(api)
        res = api_source.get_sources()
        for source in res['data']:
            name = False
            type = False
            if source['type'] == self.source_type:
                source_type = True
            if self.source_name and source['name'] in self.source_name:
                name = True
            if name and source_type:
                self.add_source_id = str(source['source_id'])
                break
        if self.add_source_id is None:
            raise ValueError('no api test source found')
        self.source_id = self.add_source_id
        res = api_profile.get_profiles(source_ids=[self.source_id])
        if not res['data']['profiles']:
            raise ValueError('no profiles found')
        profiles = res['data']['profiles']
        for profile in profiles:
            profile_id = str(profile['profile_id'])
            res = api_profile.get_scoring(source_id=self.source_id, profile_id=profile_id)
            if res['code'] != 200 or not res['data']:
                continue
            for scoring in res['data']:
                if scoring['filter_reference'] is None:
                    continue
                self.profile_id = profile_id
                self.profile_ref = profile['profile_reference']
                self.filter_id = str(scoring['filter_id'])
                self.filter_ref = str(scoring['filter_reference'])
                if scoring['rating'] is not None:
                    self.rating = int(scoring['rating'])
                if scoring['stage'] is not None:
                    self.stage = str(scoring['stage'])
                break
            # keep a valid profile but keep looking until one with a reference
            # is found.
            if not profile['profile_reference']:
                continue
            break
        if self.profile_id is None:
            raise ValueError('no valid profiles found...')

    def gen_err_msg(self, resp):
        return "Response invalid: " + str(resp)

    def gen_webhook_request(self, type):
        data = {
            'type': type,
            'message': 'pou lou lou',
            'profile': {'profile_id': '1', 'profile_reference': 'I\'m free'}
        }
        json_data = json.dumps(data)
        webhook_secret = bytes(self.webhook_secret, 'ascii')
        json_data = bytes(json_data, 'utf8')
        hasher = hmac.new(webhook_secret, json_data, hashlib.sha256)
        encoded_sign = bytes(hasher.hexdigest(), 'ascii')
        byte_encoded_sign = base64.encodebytes(encoded_sign)
        byte_json_data = base64.encodebytes(json_data)
        sign = '{}.{}'.format(byte_encoded_sign.decode('ascii'), byte_json_data.decode('ascii'))
        res = {'HTTP_RIMINDER_SIGNATURE': sign}
        return res


class TestProfile(unittest.TestCase):

    def setUp(self):
        self.helper = TestHelper()
        self.helper.setup()
        # init client and profile objects
        self.client = Riminder(api_key=self.helper.getKey())
        self.profile = Profile(self.client)

    def test_get_profiles(self):
        # get all profiles
        res = self.profile.get_profiles(source_ids=[self.helper.source_id])

        # print(res)
        self.assertEqual(res["code"], 200, msg=self.helper.gen_err_msg(res))

    def test_filter_by_seniority_and_limit_response_size(self):
        # filter profiles by seniority and limit
        # other params can be tested in the same manner
        res = self.profile.get_profiles(
            source_ids=[self.helper.source_id],
            seniority="junior",
            limit=5
            )
        self.assertEqual(res["code"], 200, msg=self.helper.gen_err_msg(res))
        self.assertLessEqual(len(res["data"]["profiles"]), 5)
        for profile in res["data"]["profiles"]:
            self.assertEqual(profile["seniority"], "junior")

    def test_post_profile(self):
        file_path = "riminder/test_assets/cv_test5.pdf"
        res = self.profile.post_profile(
            source_id=self.helper.add_source_id,
            file_path=file_path,
        )
        self.assertEqual(res["code"], 201, msg=self.helper.gen_err_msg(res))

    def test_post_profiles(self):
        dir_path = "riminder/test_assets/"
        res = self.profile.post_profiles(source_id=self.helper.add_source_id, dir_path=dir_path, is_recurcive=True)
        if len(res['fail']) > 0:
            for kf, failed in res['fail'].items():
                print('failed send: {}->{}\n', kf, failed)
        self.assertEqual(len(res['success']), 2)

    def test_get_profile(self):
        res = self.profile.get_profile(
            source_id=self.helper.source_id,
            profile_id=self.helper.profile_id,
        )
        self.assertEqual(res["code"], 200, msg=self.helper.gen_err_msg(res))

    def test_get_profile_ref(self):
        res = self.profile.get_profile(
            source_id=self.helper.source_id,
            profile_reference=self.helper.profile_ref,
        )
        errMessage = ""
        if not self.helper.profile_ref:
            errMessage = "No profile reference found: " + self.helper.gen_err_msg(res)
        self.assertEqual(res["code"], 200, msg=errMessage)

    def test_get_documents(self):
        res = self.profile.get_documents(
            source_id=self.helper.source_id,
            profile_id=self.helper.profile_id,
        )

        self.assertEqual(res["code"], 200, msg=self.helper.gen_err_msg(res))

    def test_get_documents_ref(self):
        res = self.profile.get_documents(
            source_id=self.helper.source_id,
            profile_reference=self.helper.profile_ref,
        )
        errMessage = ""
        if not self.helper.profile_ref:
            errMessage = "No profile reference found: " + self.helper.gen_err_msg(res)
        self.assertEqual(res["code"], 200, msg=errMessage)

    def test_get_parsing(self):
        res = self.profile.get_parsing(
            source_id=self.helper.source_id,
            profile_id=self.helper.profile_id,
        )

        self.assertEqual(res["code"], 200, msg=self.helper.gen_err_msg(res))

    def test_get_parsing_ref(self):
        res = self.profile.get_parsing(
            source_id=self.helper.source_id,
            profile_reference=self.helper.profile_ref,
        )
        errMessage = ""
        if not self.helper.profile_ref:
            errMessage = "No profile reference found: " + self.helper.gen_err_msg(res)
        self.assertEqual(res["code"], 200, msg=errMessage)

    def test_get_scoring(self):
        res = self.profile.get_scoring(
            source_id=self.helper.source_id,
            profile_id=self.helper.profile_id,
        )

        self.assertEqual(res["code"], 200, msg=self.helper.gen_err_msg(res))

    def test_get_scoring_ref(self):
        res = self.profile.get_scoring(
            source_id=self.helper.source_id,
            profile_reference=self.helper.profile_ref,
        )
        errMessage = ""
        if not self.helper.profile_ref:
            errMessage = "No profile reference found: " + self.helper.gen_err_msg(res)
        self.assertEqual(res["code"], 200, msg=errMessage)

    def test_update_stage(self):
        res = self.profile.update_stage(
            source_id=self.helper.source_id,
            profile_id=self.helper.profile_id,
            filter_id=self.helper.filter_id,
            stage=self.helper.stage,
        )
        self.assertEqual(res["code"], 200, msg=self.helper.gen_err_msg(res))

    def test_update_stage_ref(self):
        res = self.profile.update_stage(
            source_id=self.helper.source_id,
            profile_reference=self.helper.profile_ref,
            filter_reference=self.helper.filter_ref,
            stage=self.helper.stage,
        )
        errMessage = self.helper.gen_err_msg(res)
        if not self.helper.profile_ref or not self.helper.filter_ref:
            errMessage = "No profile reference found: " + self.helper.gen_err_msg(res)
        self.assertEqual(res["code"], 200, msg=errMessage)

    def test_update_rating(self):
        res = self.profile.update_rating(
            source_id=self.helper.source_id,
            profile_id=self.helper.profile_id,
            filter_id=self.helper.filter_id,
            rating=int(self.helper.rating),
        )
        self.assertEqual(res["code"], 200, msg=self.helper.gen_err_msg(res))

    def test_update_rating_ref(self):
        res = self.profile.update_rating(
            source_id=self.helper.source_id,
            profile_reference=self.helper.profile_ref,
            filter_reference=self.helper.filter_ref,
            rating=int(self.helper.rating),
        )
        errMessage = self.helper.gen_err_msg(res)
        if not self.helper.profile_ref or not self.helper.filter_ref:
            errMessage = "No profile reference found: " + self.helper.gen_err_msg(res)
        self.assertEqual(res["code"], 200, msg=errMessage)


class TestSource(unittest.TestCase):

    def setUp(self):
        self.helper = TestHelper()
        self.helper.setup()
        # init client and profile objects
        self.client = Riminder(api_key=self.helper.getKey())
        self.source = Source(self.client)

    def test_get_sources(self):
        # get all sources
        res = self.source.get_sources()

        # print(res)
        self.assertEqual(res["code"], 200, msg=self.helper.gen_err_msg(res))

    def test_get_source(self):
        # get one source by id
        res = self.source.get_source(
            source_id=self.helper.source_id
        )
        # print(res)
        self.assertEqual(res["code"], 200, msg=self.helper.gen_err_msg(res))


class TestFilter(unittest.TestCase):

    def setUp(self):
        self.helper = TestHelper()
        self.helper.setup()
        # init client and filter objects
        self.client = Riminder(api_key=self.helper.getKey())
        self.filter = Filter(self.client)

    def test_get_filters(self):
        # get all filters
        res = self.filter.get_filters()

        # print(res)
        self.assertEqual(res["code"], 200, msg=self.helper.gen_err_msg(res))

    def test_get_filter(self):
        # get one filter by id
        res = self.filter.get_filter(
            filter_id=self.helper.filter_id
        )
        # print(res)
        self.assertEqual(res["code"], 200, msg=self.helper.gen_err_msg(res))

    def test_get_filter_ref(self):
        # get one filter by ref
        res = self.filter.get_filter(
            filter_reference=self.helper.filter_ref
        )
        # print(res)
        self.assertEqual(res["code"], 200, msg=self.helper.gen_err_msg(res))


class TestWebhook(unittest.TestCase):

    last_evt_type = None
    last_decoded_request = None

    @staticmethod
    def handler(event_type, decoded_request):
        TestWebhook.last_evt_type = event_type
        TestWebhook.last_decoded_request = decoded_request

    def setUp(self):
        self.helper = TestHelper()
        self.helper.setup()
        self.client = Riminder(api_key=self.helper.getKey(), webhook_secret=self.helper.getWebhookSecret())
        self.webhook = Webhook(self.client)

    def test_post_check(self):
        res = self.webhook.post_check()
        self.assertEqual(res['code'], 200, msg=self.helper.gen_err_msg(res))

    def test_handle_request(self):
        self.webhook.setHandler(EVENT_FILTER_SCORE_ERROR, TestWebhook.handler)
        webhook_req = self.helper.gen_webhook_request(EVENT_FILTER_SCORE_ERROR)
        self.webhook.handleRequest(webhook_req['HTTP_RIMINDER_SIGNATURE'])
        self.assertEqual(TestWebhook.last_evt_type, EVENT_FILTER_SCORE_ERROR)
        if 'profile' not in TestWebhook.last_decoded_request:
            self.fail('Resquest is not full.')


if __name__ == '__main__':
    unittest.main()



from riminder import Riminder


class Filter(object):

    def __init__(self, client):
        if not isinstance(client, Riminder):
            raise TypeError("client must be instance of Riminder class")

        self.client = client

    def get_filters(self):
        response = self.client.get("filters")
        return response.json()

    def get_filter(self, filter_id=None, filter_reference=None):
        query_params = {}
        if filter_id:
            query_params["filter_id"] = self._validate_id(filter_id, 'filter_id')
        if filter_reference:
            query_params["filter_reference"] = self._validate_id(filter_reference, 'filter_reference')

        response = self.client.get('filter', query_params)
        return response.json()

    def _validate_id(self, value, field_name=''):
        if not isinstance(value, str) and value is not None:
            raise TypeError("{} must be string".format(field_name))

        return value



from riminder import Riminder
import time
import magic
import os
import os.path as path
import json

SERNIORITY_VALUES = ["all", "senior", "junior"]
STAGE_VALUES = [None, "NEW", "YES", "LATER", "NO"]
SORT_BY_VALUES = [None, "creation", "DESC", "reception", "ranking"]
VALID_EXTENSIONS = ['.pdf', '.png', '.jpg', '.doc', '.docx', '.rtf', '.dotx']
INVALID_FILENAME = ['.', '..']
TIMESTAMP_NOW = str(time.time())


class Profile(object):
    """Class that interacts with Riminder API profiles endpoint.

    Usage example:

    >>> from riminder import Riminder
    >>> from riminder.profile import Profile
    >>> client = Riminder(api_key="YOUR_API_KEY")
    >>> profile = Profile(self.client)
    >>> result = profile.get_profiles(source_ids=["5823bc959983f7a5925a5356020e60d605e8c9b5"])
    >>> print(result)
    {
        "code": 200,
        "message": "OK",
        "data": {
            "page": 1,
            "maxPage": 3,
            "count_profiles": 85,
            "profiles": [
            {
                "profile_id": "215de6cb5099f4895149ec0a6ac91be94ffdd246",
                "profile_reference": "49583",
                ...
    """

    def __init__(self, client):
        """
        Initialize Profile object with Riminder client.
        Args:
            client: Riminder client instance <Riminder object>

        Returns:
            Profile instance object.
        """
        if not isinstance(client, Riminder):
            raise TypeError("client must be instance of Riminder class")

        self.client = client

    def get_profiles(self, source_ids=None, seniority="all", stage=None,
                date_start="1494539999", date_end=TIMESTAMP_NOW, filter_id=None,
                page=1, limit=30, sort_by='ranking', filter_reference=None, order_by=None):
        """
        Retreive all profiles that match the query param

        Args:
            date_end:   <string> REQUIRED (default to "1502488799")
                        profiles' last date of reception
            date_start: <string> REQUIRED (default to "1494539999")
                        profiles' first date of reception
            filter_id:     <string>
            limit:      <int> (default to 30)
                        number of fetched profiles/page
            page:       <int> REQUIRED default to 1
                        number of the page associated to the pagination
            seniority:  <string> defaut to "all"
                        profiles' seniority ("all", "senior", "junior")
            sort_by:    <string>
            source_ids: <array of strings> REQUIRED
            stage:      <string>

        Returns:
            Retrieve the profiles data as <dict>
        """
        query_params = {}
        query_params["date_end"] = self._validate_date_end(date_end)
        query_params["date_start"] = self._validate_date_start(date_start)
        if filter_id:
            query_params["filter_id"] = self._validate_filter_id(filter_id)
        if filter_reference:
            query_params["filter_reference"] = self._validate_filter_reference(filter_reference)
        query_params["limit"] = self._validate_limit(limit)
        query_params["page"] = self._validate_page(page)
        query_params["seniority"] = self._validate_seniority(seniority)
        query_params["sort_by"] = self._validate_sort_by(sort_by)
        query_params["source_ids"] = json.dumps(self._validate_source_ids(source_ids))
        query_params["stage"] = self._validate_stage(stage)
        query_params["order_by"] = order_by

        response = self.client.get("profiles", query_params)
        return response.json()

    def post_profile(self, source_id=None, file_path=None, profile_reference="",
                     timestamp_reception=None, training_metadata=None):
        """
        Add a profile resume to a sourced id

        Args:
            source_id:              <string>
                                    source id
            file_path:              <string>
                                    local path to resume file
            profile_reference:      <string> (default to "")
                                    reference to assign to the profile
            timestamp_reception:    <string>
                                    original date of the application of the profile

        Returns:
            Response that contains code 201 if successful
            Other status codes otherwise.
        """
        data = {}
        data["source_id"] = self._validate_source_id(source_id)
        data["profile_reference"] = self._validate_profile_reference(profile_reference)
        data["timestamp_reception"] = self._validate_timestamp_reception(timestamp_reception)
        data["training_metadata"] = training_metadata
        files = self._get_file_metadata(file_path, profile_reference)
        response = None
        with open(file_path, 'rb') as in_file:
            files = (files[0], in_file, files[2])
            response = self.client.post("profile", data=data, files={"file": files})
        return response.json()

    def post_profiles(self, source_id, dir_path, is_recurcive=False, timestamp_reception=None, training_metadata=None):
        if not path.isdir(dir_path):
            raise ValueError(dir_path + ' is not a directory')
        files_to_send = self._get_files_from_dir(dir_path, is_recurcive)
        succeed_upload = {}
        failed_upload = {}
        for file_path in files_to_send:
            try:
                resp = self.post_profile(source_id=source_id,
                    file_path=file_path, profile_reference="",
                    timestamp_reception=timestamp_reception, training_metadata=training_metadata)
                if resp['code'] != 200 and resp['code'] != 201:
                    failed_upload[file_path] = ValueError('Invalid response: ' + str(resp))
                else:
                    succeed_upload[file_path] = resp
            except BaseException as e:
                failed_upload[file_path] = e
        result = {
            'success': succeed_upload,
            'fail': failed_upload
        }
        return result

    def get_profile(self, source_id=None, profile_id=None, profile_reference=None):
        """
        Retrieve the profile information associated with profile id

        Args:
            source_id:              <string>
                                    source id
            profile_id:             <string>
                                    profile id

        Returns:
            profile information
        """
        query_params = {}
        query_params["source_id"] = self._validate_source_id(source_id)
        if profile_id:
            query_params["profile_id"] = self._validate_profile_id(profile_id)
        if profile_reference:
            query_params["profile_reference"] = self._validate_profile_reference(profile_reference)
        response = self.client.get('profile', query_params)
        return response.json()

    def get_documents(self, source_id=None, profile_id=None, profile_reference=None):
        """
        Retrieve the file information

        Args:
            source_id:              <string>
                                    source id
            profile_id:             <string>
                                    profile id

        Returns:
            document information, like type, name, extension, url.. associated to the profile id
        """
        query_params = {}
        query_params["source_id"] = self._validate_source_id(source_id)
        if profile_id:
            query_params["profile_id"] = self._validate_profile_id(profile_id)
        if profile_reference:
            query_params["profile_reference"] = self._validate_profile_reference(profile_reference)
        response = self.client.get('profile/documents', query_params)
        return response.json()

    def get_parsing(self, source_id=None, profile_id=None, profile_reference=None):
        """
        Retrieve the parsing information

        Args:
            source_id:              <string>
                                    source id
            profile_id:             <string>
                                    profile id

        Returns:
            parsing information
        """
        query_params = {}
        query_params["source_id"] = self._validate_source_id(source_id)
        if profile_id:
            query_params["profile_id"] = self._validate_profile_id(profile_id)
        if profile_reference:
            query_params["profile_reference"] = self._validate_profile_reference(profile_reference)
        response = self.client.get('profile/parsing', query_params)
        return response.json()

    def get_scoring(self, source_id=None, profile_id=None, profile_reference=None):
        """
        Retrieve the scoring information

        Args:
            source_id:              <string>
                                    source id
            profile_id:             <string>
                                    profile id

        Returns:
            parsing information
        """
        query_params = {}
        query_params["source_id"] = self._validate_source_id(source_id)
        if profile_id:
            query_params["profile_id"] = self._validate_profile_id(profile_id)
        if profile_reference:
            query_params["profile_reference"] = self._validate_profile_reference(profile_reference)
        response = self.client.get('profile/scoring', query_params)
        return response.json()

    def update_stage(self, source_id=None, profile_id=None, filter_id=None, stage=None, profile_reference=None, filter_reference=None):
        """
        Edit the profile stage given a filter

        Args:
            profile_id:             <string>
                                    profile id
        body params:
            source_id:              <string>
                                    source id associated to the profile

            filter_id:                 <string>
                                    filter id
            stage:                 <string>
                                    profiles' stage associated to the filter ( null for all, NEW, YES, LATER or NO).

        Returns:
            Response that contains code 201 if successful
            Other status codes otherwise.
        """
        data = {}
        data["source_id"] = self._validate_source_id(source_id)
        if profile_id:
            data["profile_id"] = self._validate_profile_id(profile_id)
        if filter_id:
            data["filter_id"] = self._validate_filter_id(filter_id)
        if profile_reference:
            data["profile_reference"] = self._validate_profile_reference(profile_reference)
        if filter_reference:
            data["filter_reference"] = self._validate_filter_reference(filter_reference)
        data["stage"] = self._validate_stage(stage)

        response = self.client.patch('profile/stage', data=data)
        return response.json()

    def update_rating(self, source_id=None, profile_id=None, filter_id=None, rating=None, profile_reference=None, filter_reference=None):
        """
        Edit the profile rating given a filter

        Args:
            profile_id:             <string>
                                    profile id
        body params:
            source_id:              <string>
                                    source id associated to the profile

            filter_id:                 <string>
                                    filter id
            rating:                 <int32>
                                    profile rating from 1 to 4 associated to the filter.

        Returns:
            Response that contains code 201 if successful
            Other status codes otherwise.
        """
        data = {}
        data["source_id"] = self._validate_source_id(source_id)
        if profile_id:
            data["profile_id"] = self._validate_profile_id(profile_id)
        if filter_id:
            data["filter_id"] = self._validate_filter_id(filter_id)
        if profile_reference:
            data["profile_reference"] = self._validate_profile_reference(profile_reference)
        if filter_reference:
            data["filter_reference"] = self._validate_filter_reference(filter_reference)
        data["rating"] = self._validate_rating(rating)

        response = self.client.patch('profile/rating', data=data)
        return response.json()

    def _get_file_metadata(self, file_path, profile_reference):

        try:
            return (
                os.path.basename(file_path) + profile_reference,  # file_name
                None,
                magic.Magic(True).from_file(file_path)
            )
        except Exception as e:
            raise Exception(repr(e))

    def _validate_source_ids(self, value):
        if not isinstance(value, list):
            raise TypeError("source_ids must be a list")

        if not value or not all(isinstance(elt, str) for elt in value):
            raise TypeError("source_ids must contain list of strings")

        return value

    def _validate_source_id(self, value):
        if not isinstance(value, str) and value is not None:
            raise TypeError("source_id must be string")

        return value

    def _validate_profile_id(self, value):
        if not isinstance(value, str) and value is not None:
            raise TypeError("source_id must be string")

        return value

    def _validate_seniority(self, value):
        if value not in SERNIORITY_VALUES:
            raise ValueError("seniority value must be in {}".format(str(SERNIORITY_VALUES)))

        return value

    def _validate_stage(self, value):
        if value not in STAGE_VALUES:
            raise ValueError("stage value must be in {}".format(str(STAGE_VALUES)))

        return value

    def _validate_date_start(self, value):
        if not isinstance(value, str):
            raise TypeError("date_start must be string")

        return value

    def _validate_date_end(self, value):
        if not isinstance(value, str):
            raise TypeError("date_end must be string")

        return value

    def _validate_filter_id(self, value):
        if not isinstance(value, str) and value is not None:
            raise TypeError("filter_id must be string")

        return value

    def _validate_filter_reference(self, value):
        if not isinstance(value, str) and value is not None:
            raise TypeError("filter_reference must be string")

        return value

    def _validate_profile_reference(self, value):
        if not isinstance(value, str) and value is not None:
            raise TypeError("profile_reference must be string")

        return value

    def _validate_page(self, value):
        if not isinstance(value, int):
            raise TypeError("page must be 'int'")

        return value

    def _validate_limit(self, value):
        if not isinstance(value, int):
            raise TypeError("limit must be 'int'")

        return value

    def _validate_rating(self, value):
        if not isinstance(value, int):
            raise TypeError("rating must be 'int'")

        return value

    def _validate_sort_by(self, value):
        if value not in SORT_BY_VALUES:
            raise ValueError("sort_by value must be in {}".format(str(SORT_BY_VALUES)))

        return value

    def _validate_profile_reference(self, value):
        if not isinstance(value, str) and value is not None:
            raise TypeError("profile_reference must be string")

        return value

    def _validate_timestamp_reception(self, value):
        if not isinstance(value, str) and value is not None:
            raise TypeError("timestamp_reception must be string")

        return value

    def _is_valid_extension(self, file_path):
        ext = path.splitext(file_path)[1]
        if not ext:
            return False
        return ext in VALID_EXTENSIONS

    def _is_valid_filename(self, file_path):
        name = path.basename(file_path)
        return name not in INVALID_FILENAME

    def _get_files_from_dir(self, dir_path, is_recurcive):
        file_res = []
        files_path = os.listdir(dir_path)

        for file_path in files_path:
            true_path = path.join(dir_path, file_path)
            if path.isdir(true_path) and is_recurcive:
                if self._is_valid_filename(true_path):
                    file_res += self._get_files_from_dir(true_path, is_recurcive)
                continue
            if self._is_valid_extension(true_path):
                file_res.append(true_path)
        return file_res



from riminder import Riminder


class Source(object):

    def __init__(self, client):
        if not isinstance(client, Riminder):
            raise TypeError("client must be instance of Riminder class")

        self.client = client

    def get_sources(self):
        response = self.client.get("sources")
        return response.json()

    def get_source(self, source_id=None):
        query_params = {}
        query_params["source_id"] = self._validate_source_id(source_id)

        response = self.client.get('source', query_params)
        return response.json()

    def _validate_source_id(self, value):
        if not isinstance(value, str) and value is not None:
            raise TypeError("source_id must be string")

        return value



from setuptools import setup

setup(name='riminder',
      version='0.2.2',
      description='python riminder riminder api package',
      url='https://github.com/Riminder/python-riminder-api',
      author='mnouayti',
      author_email='contact@rimider.net',
      license='MIT',
      packages=['riminder'],
      install_requires=[
          'requests==2.18.4',
          'python-magic==0.4.15'
      ],
      zip_safe=False)
